@@ -153,7 +153,8 @@ sub SplitterWindow {
    my $media = Wx::MediaCtrl->new($righttop, -1, '', [-1,-1], [-1,-1], 0 );
    my $media2 = Wx::MediaCtrl->new($righttop, -1, '', [-1,-1], [-1,-1], 0 );
    my $media3 = Wx::MediaCtrl->new($righttop, -1, '', [-1,-1], [-1,-1], 0 );
-   my $vid="https://www.youtube.com/watch?v=dW7fXqYbXS0";
+   my $vid="https://youtu.be/QnDAaGQMRS0";
+   #my $vid="https://www.youtube.com/watch?v=dW7fXqYbXS0";
    my $vid2="Introduction_to_Amazon_Elastic_Compute_Cloud_EC2.mp4";
    $media->LoadURI("fullauto_demonstration.mp4");
    $media->Show( 1 );
@@ -172,7 +173,8 @@ sub SplitterWindow {
 
    my $webpanel='';my $webpanel2='';my $webpanel3='';
    $webpanel = Wx::Panel->new($righttop, wxID_ANY);
-   my $aws_url='https://www.youtube.com/embed/gRwa1QoOS7M';
+   #my $aws_url='https://www.youtube.com/embed/gRwa1QoOS7M';
+   my $aws_url='https://www.youtube.com/embed/QnDAaGQMRS0';
    $webpanel->{defaulturl}=$aws_url;
    my $html = Wx::WebView::New($webpanel, wxID_ANY, $webpanel->{defaulturl});
    $html->{defaulturl}=$aws_url;
@@ -749,7 +751,7 @@ print "GOING TO RUNPUTTY: runputty \"$self->{ppk_file}\" $iptext\n";
 sub dn_button {
 
    my ($self, $event) =@_;
-   my $webapp_url='http://www.fullauto.com';
+   my $webapp_url='http://www.fullauto.com/donate.html';
    Wx::LaunchDefaultBrowser($webapp_url,wxBROWSER_NEW_WINDOW);
 
 }
